Template

Certificamos que, Melissa Ribeiro Araujo , CPF 201.544.482-30 , participou do evento de extensão Nome do Curso , com carga horária de Carga Horaria hora(s), coordenado pelo(a) Professor(a) Nome do Professor , promovido pelo(a) Nome do Departamento , na função de MONITOR , com frequência 97 %. A atividade foi realizada no período de Data Inicial a Data Final .

Brasília, 20 de Janeiro de 2023

Nome Decana

Decano(a) de Extensão